LavaDirection enum

Inheritance
Available extensions

Values

n → const LavaDirection

North

const LavaDirection(90.0)
nne → const LavaDirection

North-Northeast

const LavaDirection(67.5)
ne → const LavaDirection

Northeast

const LavaDirection(45.0)
ene → const LavaDirection

East-Northeast

const LavaDirection(22.5)
e → const LavaDirection

East

const LavaDirection(0.0)
ese → const LavaDirection

East-Southeast

const LavaDirection(337.5)
se → const LavaDirection

Southeast

const LavaDirection(315.0)
sse → const LavaDirection

South-Southeast

const LavaDirection(292.5)
s → const LavaDirection

South

const LavaDirection(270.0)
ssw → const LavaDirection

South-Southwest

const LavaDirection(247.5)
sw → const LavaDirection

Southwest

const LavaDirection(225.0)
wsw → const LavaDirection

West-Southwest

const LavaDirection(202.5)
w → const LavaDirection

West

const LavaDirection(180.0)
wnw → const LavaDirection

West-Northwest

const LavaDirection(157.5)
nw → const LavaDirection

Northwest

const LavaDirection(135.0)
nnw → const LavaDirection

North-Northwest

const LavaDirection(112.5)

Properties

degrees → double
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
opposite → LavaDirection
Returns the opposite direction of this direction.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bounceOffWall(bool vertical) → LavaDirection
Returns the direction to bounce off a wall.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LavaDirection>
A constant List of the values in this enum, in order of their declaration.