Lava class

This is the data needed to paint a circle in the lava lamp pattern.

Constructors

Lava({required double width, required double widthTolerance, required bool growAndShrink, required double growthRate, required double growthRateTolerance, required double blurLevel, required List<Color> colors, required bool allSameColor, required bool fadeBetweenColors, required bool changeColorsTogether, required double speed, required double speedTolerance})
Creates a new Lava object.

Properties

allSameColor → bool
Whether or not all circles should be the same color.
final
blurLevel → double
How extreme the blur effect should be. The higher the number, the more extreme the blur effect.
final
changeColorsTogether → bool
Whether or not the circles should change colors together.
final
color ↔ Color
The current color of this circle.
getter/setter pair
colors → List<Color>
The colors of the circles that will be moving on the screen.
final
direction ↔ LavaDirection
The direction this circle is moving.
getter/setter pair
fadeBetweenColors → bool
Whether or not each circle should fade between colors.
final
growAndShrink → bool
Whether or not the circles should grow and shrink.
final
growthRate ↔ double
The rate at which the circle will grow and shrink.
getter/setter pair
growthRateTolerance → double
The amount more or less than the set growthRate that the circles can grow and shrink.
final
hashCode → int
The hash code for this object.
no setteroverride
position ↔ Offset
The current position of this circle.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed ↔ double
The speed that the lava blobs will move across the screen.
getter/setter pair
speedTolerance → double
The tolerance for the speed of the lava blobs.
final
width ↔ double
The width of this circle.
getter/setter pair
widthTolerance → double
The amount more or less than the set width that the circles can be.
final

Methods

copy() → Lava
Returns a copy of this object.
copyWith({double? width, double? widthTolerance, bool? growAndShrink, double? growthRate, double? growthRateTolerance, double? blurLevel, List<Color>? colors, bool? allSameColor, bool? fadeBetweenColors, bool? changeColorsTogether, double? speed, double? speedTolerance}) → Lava
Returns a copy of this object with its field values replaced by the ones provided to this method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stepForward(double animationValue) → void
Returns the data for the next step of this circle in the lava lamp pattern.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

initPosition → const Offset
The initial position of the circle when a new circle is created.