LavaPainterData class

The data needed to paint a wave background.

A wave background is a background that has gently flowing sine waves that move across the screen in a certain direction.

Inheritance

Constructors

LavaPainterData({double width = 200.0, double widthTolerance = 0.0, bool growAndShrink = false, double growthRate = 20.0, double growthRateTolerance = 0.0, double blurLevel = 25.0, int numBlobs = 5, Color backgroundColor = Colors.transparent, required List<Color> colors, bool allSameColor = false, bool fadeBetweenColors = true, bool changeColorsTogether = false, double speed = 20.0, double speedTolerance = 0.0})
Creates a new LavaPainterData object.

Properties

allSameColor → bool
Whether or not all circles should be the same color.
final
backgroundColor → Color
The color of the background behind the circles.
final
blobs → List<Lava>
The list of circles that will be moving on the screen.
no setter
blurLevel → double
How extreme the blur effect should be. The higher the number, the more extreme the blur effect.
final
changeColorsTogether → bool
Whether or not the circles should change colors together.
final
colors → List<Color>
The colors of the circles that will be moving on the screen.
no setter
fadeBetweenColors → bool
Whether or not each circle should fade between colors.
final
growAndShrink → bool
Whether or not the circles should grow and shrink.
final
growthRate ↔ double
The rate at which the circle will grow and shrink.
getter/setter pair
growthRateTolerance → double
The amount more or less than the set growthRate that the circles can grow and shrink.
final
hashCode → int
Note: The order of the elements in the colors list is important—if the two objects have the same colors but in a different order, they will not have the same hash code.
no setteroverride
numBlobs → int
The number of circles that will be moving on the screen.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → double
The speed that the lava blobs will move across the screen.
final
speedTolerance → double
The tolerance for the speed of the lava blobs.
final
width → double
The width of the circles that will be moving on the screen.
final
widthTolerance → double
The amount more or less than the set width that the circles can be.
final

Methods

addAllColors(List<Color> colors) → void
Adds a list of colors to the end of the list of colors.
addColor(Color color) → void
Adds a color to the end of the list of colors.
copy() → LavaPainterData
Returns a copy of this object.
override
copyWith({double? width, double? widthTolerance, bool? growAndShrink, double? growthRate, double? growthRateTolerance, double? blurLevel, int? numBlobs, Color? backgroundColor, List<Color>? colors, bool? allSameColor, bool? fadeBetweenColors, bool? changeColorsTogether, double? speed, double? speedTolerance}) → LavaPainterData
Returns a copy of this object with its field values replaced by the ones provided to this method.
override
getPainter(Animation<double> animation) → Painter
Returns a Painter object that will paint the background.
override
insertAllColors(int index, List<Color> colors) → void
Adds a list of colors at the given index in the list of colors.
insertColor(int index, Color color) → void
Adds a color at the given index in the list of colors.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeColor(Color color) → bool
Removes the first occurrence of the given color from the list of colors.
removeColorAt(int index) → Color?
Removes the color at the given index from the list of colors.
removeColorCompletely(Color color) → bool
Removes all occurrences of the given color from the list of colors.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
Note: The order of the elements in the colors list is important—if the two objects have the same colors but in a different order, they will not be considered equal.
override