PainterData class abstract

This is an abstract class that is used to create blueprints for drawing the background.

Implementers

Constructors

PainterData()
Creates a PainterData object.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → PainterData
Returns a copy of this object.
copyWith() → PainterData
Returns a copy of this object with its field values replaced by the ones provided to this method.
getPainter(Animation<double> animation) → Painter
Returns a Painter object that will paint the background.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited