ScrollerPainterData class

The data needed to paint a scroller background.

A scroller background is a background that has shapes that move across the screen in a certain direction.

Inheritance

Constructors

ScrollerPainterData({ScrollDirection direction = ScrollDirection.right2Left, ScrollerShape shape = ScrollerShape.circles, required Color backgroundColor, required Color color, double shapeWidth = 24.0, double spaceBetweenShapes = 24.0, bool fadeEdges = true, ScrollerShapeOffset shapeOffset = ScrollerShapeOffset.none})
Creates a new ScrollerPainterData object.
const

Properties

backgroundColor → Color
The color of the background behind the scrolling shapes.
final
color → Color
The color of the shapes that will be scrolling.
final
direction → ScrollDirection
The direction the scroller should move in.
final
fadeEdges → bool
Whether or not to fade the shapes that are entering or exiting the screen.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ScrollerShape
The shapes that will be scrolling across the screen.
final
shapeHeight → double
The height of the shapes that will be scrolling.
no setter
shapeOffset → ScrollerShapeOffset
How to align the shapes that will be scrolling.
final
shapeWidth → double
The width of the shapes that will be scrolling.
final
spaceBetweenShapes → double
The width of the space between the shapes that will be scrolling.
final

Methods

copy() → ScrollerPainterData
Returns a copy of this object.
override
copyWith({ScrollDirection? direction, ScrollerShape? shape, Color? backgroundColor, Color? color, double? shapeWidth, double? spaceBetweenShapes, bool? fadeEdges, ScrollerShapeOffset? shapeOffset}) → ScrollerPainterData
Returns a copy of this object with its field values replaced by the ones provided to this method.
override
getPainter(Animation<double> animation) → Painter
Returns a Painter object that will paint the background.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override