Wave class

Constructors

Wave({WaveDirection direction = WaveDirection.right2Left, WaveGravityDirection gravityDirection = WaveGravityDirection.down, double amplitude = 40.0, int frequency = 1, double phase = 0.0, double offset = 0.75, bool useScaledOffset = true, required Color color, Color? lineColor, double lineThickness = 2.0})
Creates a new Wave object.
const

Properties

amplitude → double
The amplitude of the wave.
final
color → Color
The color of the space below the wave.
final
direction → WaveDirection
The direction the wave should move.
final
frequency → int
The frequency of the wave.
final
gravityDirection → WaveGravityDirection
The direction that should be considered the bottom of the wave.
final
hashCode → int
The hash code for this object.
no setteroverride
lineColor → Color?
The color of the line.
final
lineThickness → double
The thickness of the line.
final
offset → double
The x or y coordinate of the center line of the wave, depending on the direction.
final
phase → double
The phase of the wave.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useScaledOffset → bool
Whether of not the offset should be scaled to the available canvas size.
final

Methods

copy() → Wave
Returns a copy of this object.
copyWith({WaveDirection? direction, WaveGravityDirection? gravityDirection, double? amplitude, int? frequency, double? phase, double? offset, bool? useScaledOffset, Color? color, Color? lineColor = _sentinelValue, double? lineThickness}) → Wave
Returns a copy of this object with its field values replaced by the ones provided to this method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override