utils/math_tools library

Functions

deg2Rad(num deg) → double
This method converts degrees to radians.
rad2Deg(num rad) → double
This method converts radians to degrees.
randDouble(double min, double max) → double
This method generates and returns a random double from min to max (inclusive).
randInt(int min, int max) → int
This method generates and returns a random integer from min to max (inclusive).
randIntExcluding(int min, int max, int exclude) → int
This method generates and returns a random integer from min to max (inclusive), excluding exclude.